@@ -8,7 +8,7 @@ class GunicornInstall(Task):
 
     name = 'setup'
 
-    def run(self):
+    def run(self, env_value=None):
         """
         """
 
@@ -19,4 +19,8 @@ class GunicornInstall(Task):
         sudo('logadm -C 3 -p1d -c -w /var/log/gunicorn/django.log -z 1')
         run('svccfg import /srv/active/deploy/gunicorn/gunicorn.xml')
 
+        if env_value:
+            run('svccfg -s gunicorn setenv %s %s' % (env.project_env_var,
+                                                    env_value))
+
 setup = GunicornInstall()
